/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.model;

import java.util.ArrayList;
import sa.shpi.advanced.model.content.FurnishingLibrary;

import sa.shpi.advanced.model.content.Room;
import sa.shpi.advanced.model.shelf.Shelf;
import sa.shpi.advanced.model.structure.MaterialsLibraryRoofing;
import sa.shpi.advanced.model.structure.MaterialsLibraryExtWalls;
import sa.shpi.advanced.model.structure.MaterialsLibraryFlooring;
import sa.shpi.advanced.model.structure.Section;
import sa.shpi.advanced.model.structure.SectionCategory;

/**
 * Class for the warehouse building. This class stores all information about
 * the building and its components. It also stores a running total for the area
 * of all rooms added to the building.
 *
 * @author Kyle
 *
 */

public class Warehouse {

    private String name;
    private ArrayList<Room> rooms;
    private ArrayList<Shelf> shelves;
    private Section externalWalls = new Section(SectionCategory.EXTERNAL_WALLS);
    private Section flooring = new Section(SectionCategory.FLOORING);
    private Section roofing = new Section(SectionCategory.ROOFING);
    private static double areaTotal;
    private static double areaBurned;
    private MaterialsLibraryRoofing materialsLibrary;
    private FurnishingLibrary furnishingsLibrary;
    private static double totalRoomArea;
    private SectionCategory sectionCategory;
    
    public void setWareSectionCategory(SectionCategory sectionCat) {
        this.sectionCategory = sectionCat;
    }

    public static void addTotalRoomArea(double roomarea) {
        totalRoomArea += roomarea;
    }
    
    public static double getTotalRoomArea() {
        return totalRoomArea;
    }

    public void setFurnishingsLibrary(FurnishingLibrary furnishingsLibrary) {
        this.furnishingsLibrary = furnishingsLibrary;
    }

    public FurnishingLibrary getFurnishingsLibrary() {
        return furnishingsLibrary;
    }

    public MaterialsLibraryRoofing getMaterialsLibrary() {
        return materialsLibrary;
    }

    public void setMaterialsLibrary(MaterialsLibraryRoofing materialsLibrary) {
        this.materialsLibrary = materialsLibrary;
    }

    public void initializelibrary() {
        //Depending on selected section, initialize appropriate library.
        if (sectionCategory.equals(SectionCategory.EXTERNAL_WALLS)) {
            setMaterialsLibrary(new MaterialsLibraryExtWalls());
        } else if (sectionCategory.equals(SectionCategory.FLOORING)) {
            setMaterialsLibrary(new MaterialsLibraryFlooring());
        } else if (sectionCategory.equals(SectionCategory.ROOFING)) {
            setMaterialsLibrary(new MaterialsLibraryRoofing());
        }
    }
    
    public void initializefurnlibrary() {
        setFurnishingsLibrary(new FurnishingLibrary());
    }

    public Warehouse() {
        name = Strings.WAREHOUSE.toString();
        rooms = new ArrayList<Room>();
        shelves = new ArrayList<Shelf>();
    }

    public Warehouse(String name) {
        this.name = name;
        rooms = new ArrayList<Room>();
        shelves = new ArrayList<Shelf>();
    }

    public ArrayList<Room> getRooms() {
        return rooms;
    }

    public void setRooms(ArrayList<Room> rooms) {
        this.rooms = rooms;
    }
    
    public void addRoom(Room room) {
        rooms.add(room);
    }
    
    public ArrayList<Shelf> getShelves() {
        return shelves;
    }

    public void setShelves(ArrayList<Shelf> shelves) {
        this.shelves = shelves;
    }
    
    public void addShelf(Shelf shelf) {
        shelves.add(shelf);
    }

    public Section getExternalWalls() {
        return externalWalls;
    }

    public void setExternalWalls(Section externalWalls) {
        this.externalWalls = externalWalls;
    }

    public Section getFlooring() {
        return flooring;
    }

    public void setFlooring(Section flooring) {
        this.flooring = flooring;
    }

    public Section getRoofing() {
        return roofing;
    }

    public void setRoofing(Section roofing) {
        this.roofing = roofing;
    }

    public static double getAreaTotal() {
        return areaTotal;
    }

    public void setAreaTotal(double areaTotal) {
        Warehouse.areaTotal = areaTotal;
    }

    public static double getAreaBurned() {
        return areaBurned;
    }

    public void setAreaBurned(double areaBurned) {
        this.areaBurned = areaBurned;
    }

    public double getTotalEmissions() {
        return getContentEmissions() + getStructureEmissions() + getShelfEmissions();
    }

    public double getContentEmissions() {
        double emissions = 0.0;
        //For each room:
        for (int count = 0; count < rooms.size(); count++) {
            //Add the emissions from the room together.
            emissions += rooms.get(count).calculateEmissions();
        }
        return emissions;
    }
    
    public double getShelfEmissions() {
        double emissions = 0.0;
        //For each shelf:
        for (int count = 0; count < shelves.size(); count++) {
            //Add the emissions from the shelf together.
            emissions += shelves.get(count).calculateEmissions();
        }
        return emissions;
    }

    public double getStructureEmissions() {
        double emissions = 0.0;
        //For each structural component:
        for (int count = 0; count < getSections().size(); count++) {
            //Add the emissions from each section together.
            emissions += getSections().get(count)
                    .calculateEmissions(areaBurned);
        }
        return emissions;
    }

    @Override
    public String toString() {
        return name + String.format(" (%.2f kg CO2)", getTotalEmissions()); 
    }

    public Section getSection(SectionCategory section) {
        if (section == SectionCategory.EXTERNAL_WALLS) {
            return externalWalls;
        } else if (section == SectionCategory.FLOORING) {
            return flooring;
        } else if (section == SectionCategory.ROOFING) {
            return roofing;
        } else {
            return null;
        }
    }

    public ArrayList<Section> getSections() {
        ArrayList<Section> sectionList = new ArrayList<Section>();
        sectionList.add(externalWalls);
        sectionList.add(roofing);
        sectionList.add(flooring);
        return sectionList;
    }

}
