/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.model.content;

import javax.swing.JOptionPane;
import sa.shpi.advanced.model.Industrial;
import sa.shpi.advanced.model.Strings;
import sa.shpi.advanced.model.IndustrialType;

/**
 * A basic room in a industrial building. Stores information relating to the
 * area of the room, the percent of damage in the room, and the furnishings in
 * the room.
 * 
 * Specific industrial rooms store information regarding type of content and mass
 * of content.
 *
 * @author Kyle
 *
 */
public class Room {

    private RoomType roomType;
    private FurnishingList furnishingList;
    private int damage;
    private double roomarea;
    private int roomquantity;
    private double fuelVolume;
    private FuelType fuelType;
    private FinGoodType finGoodType;
    private double matMass;
    private RawMatType rawMatType;
    private double rawMatMass;
    private double otherEmisFac;
    private FinGoodStorageType finGoodStorage;
    private RawMatStorageType rawMatStorage;
    
    public void setRawMatStorageType(RawMatStorageType rawmatstoragetype) {
        this.rawMatStorage = rawmatstoragetype;
    }
    
    public RawMatStorageType getRawMatStorageType() {
        return rawMatStorage;
    }
    
    public void setFinGoodStorageType(FinGoodStorageType fingoodstoragetype) {
        this.finGoodStorage = fingoodstoragetype;
    }
    
    public FinGoodStorageType getFinGoodStorageType() {
        return finGoodStorage;
    }
    
    public void setOtherEmisFac(double factor) {
        this.otherEmisFac = factor;
    }
    
    public double getOtherEmisFac() {
        return otherEmisFac;
    }
    
    public void setRawMatMass(double mass) {
        this.rawMatMass = mass;
    }
    
    public double getRawMatMass() {
        return rawMatMass;
    }
    
    public void setRawMatType(RawMatType rawmattype) {
        this.rawMatType = rawmattype;
    }
    
    public RawMatType getRawMatType() {
        return rawMatType;
    }
    
    public void setMatMass(double matmass) {
        this.matMass = matmass;
    }
    
    public double getMatMass() {
        return matMass;
    }
    
    public void setFinGoodType(FinGoodType fingoodtype) {
        this.finGoodType = fingoodtype;
    }
    
    public FinGoodType getFinGoodType() {
        return finGoodType;
    }
    
    public void setFuelType(FuelType fueltype) {
        this.fuelType = fueltype;
    }
    
    public FuelType getFuelType() {
        return fuelType;
    }
    
    public void setFuelVolume(double fuelvolume) {
        this.fuelVolume = fuelvolume;
    }
    
    public double getFuelVolume() {
        String fuelVolumeString = String.format("%.2f", fuelVolume);
        return Double.parseDouble(fuelVolumeString);
    }

    public Room() {
        this.furnishingList = new FurnishingList();
    }

    public Room(RoomType roomType) {
        this.roomType = roomType;
        this.furnishingList = new FurnishingList();
    }

    public void setRoomType(RoomType roomType) {
        this.roomType = roomType;
    }

    public RoomType getRoomType() {
        return roomType;
    }

    public void setRoomArea(double roomarea) {
        this.roomarea = roomarea;
    }

    public double getRoomArea() {
        String roomAreaString = String.format("%.2f", roomarea);
        return Double.parseDouble(roomAreaString);
    }
    
    public void setRoomQuantity(int roomquantity) {
        this.roomquantity = roomquantity;
    }
    
    public int getRoomQuantity() {
        return roomquantity;
    }

    public void addFurnishing(UsedFurnishing furnishing) {
        //Validate that default rooms do not use other furnishings.
        if (furnishing.toString().contains(Strings.DEFAULT_LOADING.toString())) {
            if (furnishingList.size() >= 1) {
                JOptionPane.showMessageDialog(null, Strings.DEFAULT_PLUS);
            } else if (furnishing.getQuantity() > 1) {
                JOptionPane.showMessageDialog(null, Strings.DEFAULT_PLUS);
            } else furnishingList.add(furnishing);
        } else if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
            JOptionPane.showMessageDialog(null, Strings.DEFAULT_PLUS);
        } else furnishingList.add(furnishing);

    }

    public void setFurnishingList(FurnishingList furnishingList) {
        this.furnishingList = furnishingList;
    }

    public FurnishingList getFurnishingList() {
        return furnishingList;
    }

    public double calculateEmissions() {
        double emissions = 0.0;
        double storageemissions = 0.0;

        /**
         * The following calculations differentiate emissions based on type of
         * industrial building, type of affected room, and contents added to the
         * room.
         *
         * Rooms that use a default loading multiply the rooms
         * area by an average loading for that type of room.
         *
         * Rooms that do not use a default fire loading simply total the
         * emissions from all furnishings added to the room.
         * 
         * Production floors tally the emissions from raw materials
         * and finished goods.
         * 
         * Raw material storage tallies emissions from raw materials and their
         * storage containers.  Finished goods storage works similarly.
         */
        //Differentiate emissions based on type of industrial buiding.
        if (Industrial.getIndustrialType().equals(IndustrialType.FOOD_IND)) {
            //Differentiate emissions based on type of room.
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                /**
                 * The production floor emissions are calculated by adding the
                 * emissions from raw materials on the floor to the emissions from
                 * finished goods on the floor.
                 * 
                 * All emissions are calculated using the mass of product multiplied
                 * by the emissions factor for that category.
                 */
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                //Differentiate emissions based on type of material.
                if (rawMatType.equals(RawMatType.FOOD)){
                    rawMatEmissions = rawMatMass * 1.692;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.BEANS)){
                    rawMatEmissions = rawMatMass * 0.88;
                } else if (rawMatType.equals(RawMatType.BEEF)){
                    rawMatEmissions = rawMatMass * 1.987;
                } else if (rawMatType.equals(RawMatType.BUTTER)){
                    rawMatEmissions = rawMatMass * 1.7;
                } else if (rawMatType.equals(RawMatType.CHICKEN)){
                    rawMatEmissions = rawMatMass * 1.942;
                } else if (rawMatType.equals(RawMatType.CORN)){
                    rawMatEmissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.FISH)){
                    rawMatEmissions = rawMatMass * 2.185;
                } else if (rawMatType.equals(RawMatType.LAMB)){
                    rawMatEmissions = rawMatMass * 2.340;
                } else if (rawMatType.equals(RawMatType.OATS)){
                    rawMatEmissions = rawMatMass * 1.33;
                } else if (rawMatType.equals(RawMatType.PORK)){
                    rawMatEmissions = rawMatMass * 2.538;
                } else if (rawMatType.equals(RawMatType.POTATOES)){
                    rawMatEmissions = rawMatMass * 0.17;
                } else if (rawMatType.equals(RawMatType.RICE)){
                    rawMatEmissions = rawMatMass * 1.43;
                } else if (rawMatType.equals(RawMatType.SOY)){
                    rawMatEmissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.SUGARCANE)){
                    rawMatEmissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.TURKEY)){
                    rawMatEmissions = rawMatMass * 2.693;
                } else if (rawMatType.equals(RawMatType.WHEAT)){
                    rawMatEmissions = rawMatMass * 1.63;
                }
                if (finGoodType.equals(FinGoodType.ALCOHOL)){
                    finGoodEmissions = matMass * 0.6125;
                } else if (finGoodType.equals(FinGoodType.CANNED)){
                    finGoodEmissions = matMass * 0.2;
                } else if (finGoodType.equals(FinGoodType.DAIRY)){
                    finGoodEmissions = matMass * 1.686;
                } else if (finGoodType.equals(FinGoodType.GRAIN)){
                    finGoodEmissions = matMass * 3.5825;
                } else if (finGoodType.equals(FinGoodType.MEAT)){
                    finGoodEmissions = matMass * 1.033;
                } else if (finGoodType.equals(FinGoodType.PRODUCE)){
                    finGoodEmissions = matMass * 2.385;
                } else if (finGoodType.equals((FinGoodType.FOOD))){
                    finGoodEmissions = matMass * 1.5832;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                /**
                 * Raw Material Storage emissions are calculated by multiplying
                 * the mass of material in storage by the emissions factor for that
                 * material.
                 * 
                 * The user may input mass of material, or volume and density
                 * of material.
                 */
                if (rawMatType.equals(RawMatType.FOOD)){
                    emissions = rawMatMass * 1.692;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.BEANS)){
                    emissions = rawMatMass * 0.88;
                } else if (rawMatType.equals(RawMatType.BEEF)){
                    emissions = rawMatMass * 1.987;
                } else if (rawMatType.equals(RawMatType.BUTTER)){
                    emissions = rawMatMass * 1.7;
                } else if (rawMatType.equals(RawMatType.CHICKEN)){
                    emissions = rawMatMass * 1.942;
                } else if (rawMatType.equals(RawMatType.CORN)){
                    emissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.FISH)){
                    emissions = rawMatMass * 2.185;
                } else if (rawMatType.equals(RawMatType.LAMB)){
                    emissions = rawMatMass * 2.340;
                } else if (rawMatType.equals(RawMatType.OATS)){
                    emissions = rawMatMass * 1.33;
                } else if (rawMatType.equals(RawMatType.PORK)){
                    emissions = rawMatMass * 2.538;
                } else if (rawMatType.equals(RawMatType.POTATOES)){
                    emissions = rawMatMass * 0.17;
                } else if (rawMatType.equals(RawMatType.RICE)){
                    emissions = rawMatMass * 1.43;
                } else if (rawMatType.equals(RawMatType.SOY)){
                    emissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.SUGARCANE)){
                    emissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.TURKEY)){
                    emissions = rawMatMass * 2.693;
                } else if (rawMatType.equals(RawMatType.WHEAT)){
                    emissions = rawMatMass * 1.63;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                /**
                 * Finished goods storage is calculated in the same manner
                 * as raw materials storage, but uses a different list of materials.
                 */
                if (finGoodType.equals(FinGoodType.ALCOHOL)) {
                    emissions = matMass * 0.6125;
                } else if (finGoodType.equals(FinGoodType.CANNED)) {
                    emissions = matMass * 0.2;
                } else if (finGoodType.equals(FinGoodType.DAIRY)) {
                    emissions = matMass * 1.686;
                } else if (finGoodType.equals(FinGoodType.GRAIN)) {
                    emissions = matMass * 3.5825;
                } else if (finGoodType.equals(FinGoodType.MEAT)) {
                    emissions = matMass * 1.033;
                } else if (finGoodType.equals(FinGoodType.PRODUCE)) {
                    emissions = matMass * 2.385;
                } else if (finGoodType.equals(FinGoodType.FOOD)) {
                    emissions = matMass * 1.5832;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        } else if (Industrial.getIndustrialType().equals(IndustrialType.CHEM_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.CHEM)){
                    rawMatEmissions = rawMatMass * 1.539;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.ACETIC_ACID)){
                    rawMatEmissions = rawMatMass * 1.47;
                } else if (rawMatType.equals(RawMatType.ACETONE)){
                    rawMatEmissions = rawMatMass * 2.28;
                } else if (rawMatType.equals(RawMatType.AMMONIA)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.AMM_NITRATE)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.BENZENE)){
                    rawMatEmissions = rawMatMass * 3.38;
                } else if (rawMatType.equals(RawMatType.BISPHENOL)){
                    rawMatEmissions = rawMatMass * 2.89;
                } else if (rawMatType.equals(RawMatType.CARBON_BLACK)){
                    rawMatEmissions = rawMatMass * 3.66;
                } else if (rawMatType.equals(RawMatType.CHLORINE)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.CYCLOHEXANE)){
                    rawMatEmissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.ETHYLENE)){
                    rawMatEmissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.ETHYLENE_DI)){
                    rawMatEmissions = rawMatMass * 0.89;
                } else if (rawMatType.equals(RawMatType.ETHYLENE_GLYCOL)){
                    rawMatEmissions = rawMatMass * 1.42;
                } else if (rawMatType.equals(RawMatType.ETHYL_OX)){
                    rawMatEmissions = rawMatMass * 1.00;
                } else if (rawMatType.equals(RawMatType.FORMALDEHYDE)){
                    rawMatEmissions = rawMatMass * 1.47;
                } else if (rawMatType.equals(RawMatType.HYDROCHLORIC)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.ISOBUTYLENE)){
                    rawMatEmissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.METHANOL)){
                    rawMatEmissions = rawMatMass * 1.38;
                } else if (rawMatType.equals(RawMatType.NITRIC_ACID)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.NITROGEN)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.OXYGEN)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.PHENOL)){
                    rawMatEmissions = rawMatMass * 2.81;
                } else if (rawMatType.equals(RawMatType.PHOS_ACID)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.POTASH)){
                    rawMatEmissions = rawMatMass * 0.32;
                } else if (rawMatType.equals(RawMatType.PROPYLENE)){
                    rawMatEmissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.PROP_OX)){
                    rawMatEmissions = rawMatMass * 2.28;
                } else if (rawMatType.equals(RawMatType.SOD_CARB)){
                    rawMatEmissions = rawMatMass * 2.8;
                } else if (rawMatType.equals(RawMatType.SOD_HYDRO)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.SOD_SILI)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.STYRENE)){
                    rawMatEmissions = rawMatMass * 3.38;
                } else if (rawMatType.equals(RawMatType.SULF_ACID)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.TEREPHTALIC_ACID)){
                    rawMatEmissions = rawMatMass * 2.12;
                } else if (rawMatType.equals(RawMatType.TITANIUM_DIOX)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.UREA)){
                    rawMatEmissions = rawMatMass * 0.73;
                } else if (rawMatType.equals(RawMatType.VC)){
                    rawMatEmissions = rawMatMass * 1.41;
                } else if (rawMatType.equals(RawMatType.VINYL_ACE)){
                    rawMatEmissions = rawMatMass * 2.05;
                } else if (rawMatType.equals(RawMatType.XYLENE)){
                    rawMatEmissions = rawMatMass * 3.32;
                }
                //Emissions are written as (mass) * (emissions factor)
                if (finGoodType.equals(FinGoodType.CHEM)){
                    finGoodEmissions = matMass * 1.632;
                } else if (finGoodType.equals(FinGoodType.POOL_CHEM)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.PAINT)){
                    finGoodEmissions = matMass * 3.35;
                } else if (finGoodType.equals(FinGoodType.ANTIFREEZE)){
                    finGoodEmissions = matMass * 2.0;
                } else if (finGoodType.equals(FinGoodType.RODENTICIDE)){
                    finGoodEmissions = matMass * 2.75;
                } else if (finGoodType.equals(FinGoodType.AP_CLEANER)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.LAUNDRY)){
                    finGoodEmissions = matMass * 1.69;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.CHEM)){
                    emissions = rawMatMass * 1.539;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.ACETIC_ACID)){
                    emissions = rawMatMass * 1.47;
                } else if (rawMatType.equals(RawMatType.ACETONE)){
                    emissions = rawMatMass * 2.28;
                } else if (rawMatType.equals(RawMatType.AMMONIA)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.AMM_NITRATE)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.BENZENE)){
                    emissions = rawMatMass * 3.38;
                } else if (rawMatType.equals(RawMatType.BISPHENOL)){
                    emissions = rawMatMass * 2.89;
                } else if (rawMatType.equals(RawMatType.CARBON_BLACK)){
                    emissions = rawMatMass * 3.66;
                } else if (rawMatType.equals(RawMatType.CHLORINE)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.CYCLOHEXANE)){
                    emissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.ETHYLENE)){
                    emissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.ETHYLENE_DI)){
                    emissions = rawMatMass * 0.89;
                } else if (rawMatType.equals(RawMatType.ETHYLENE_GLYCOL)){
                    emissions = rawMatMass * 1.42;
                } else if (rawMatType.equals(RawMatType.ETHYL_OX)){
                    emissions = rawMatMass * 1.00;
                } else if (rawMatType.equals(RawMatType.FORMALDEHYDE)){
                    emissions = rawMatMass * 1.47;
                } else if (rawMatType.equals(RawMatType.HYDROCHLORIC)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.ISOBUTYLENE)){
                    emissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.METHANOL)){
                    emissions = rawMatMass * 1.38;
                } else if (rawMatType.equals(RawMatType.NITRIC_ACID)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.NITROGEN)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.OXYGEN)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.PHENOL)){
                    emissions = rawMatMass * 2.81;
                } else if (rawMatType.equals(RawMatType.PHOS_ACID)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.POTASH)){
                    emissions = rawMatMass * 0.32;
                } else if (rawMatType.equals(RawMatType.PROPYLENE)){
                    emissions = rawMatMass * 3.14;
                } else if (rawMatType.equals(RawMatType.PROP_OX)){
                    emissions = rawMatMass * 2.28;
                } else if (rawMatType.equals(RawMatType.SOD_CARB)){
                    emissions = rawMatMass * 2.8;
                } else if (rawMatType.equals(RawMatType.SOD_HYDRO)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.SOD_SILI)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.STYRENE)){
                    emissions = rawMatMass * 3.38;
                } else if (rawMatType.equals(RawMatType.SULF_ACID)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.TEREPHTALIC_ACID)){
                    emissions = rawMatMass * 2.12;
                } else if (rawMatType.equals(RawMatType.TITANIUM_DIOX)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.UREA)){
                    emissions = rawMatMass * 0.73;
                } else if (rawMatType.equals(RawMatType.VC)){
                    emissions = rawMatMass * 1.41;
                } else if (rawMatType.equals(RawMatType.VINYL_ACE)){
                    emissions = rawMatMass * 2.05;
                } else if (rawMatType.equals(RawMatType.XYLENE)){
                    emissions = rawMatMass * 3.32;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.CHEM)){
                    emissions = matMass * 1.632;
                } else if (finGoodType.equals(FinGoodType.POOL_CHEM)){
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.PAINT)){
                    emissions = matMass * 3.35;
                } else if (finGoodType.equals(FinGoodType.ANTIFREEZE)){
                    emissions = matMass * 2.0;
                } else if (finGoodType.equals(FinGoodType.RODENTICIDE)){
                    emissions = matMass * 2.75;
                } else if (finGoodType.equals(FinGoodType.AP_CLEANER)){
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.LAUNDRY)){
                    emissions = matMass * 1.69;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        }  else if (Industrial.getIndustrialType().equals(IndustrialType.METAL_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.METAL)){
                    rawMatEmissions = rawMatMass * 0.0039;
                } else if (rawMatType.equals(RawMatType.OTHER)) {
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.ALUMINUM)) {
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.STEEL)) {
                    rawMatEmissions = rawMatMass * 0.0117;
                } else if (rawMatType.equals(RawMatType.IRON)) {
                    rawMatEmissions = rawMatMass * 0;
                }
                if (finGoodType.equals(FinGoodType.METAL)){
                    finGoodEmissions = matMass * 0.0042;
                } else if (finGoodType.equals(FinGoodType.ALUMINUM)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.COPPER)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.IRON)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.STEEL)){
                    finGoodEmissions = matMass * 0.0117;
                } else if (finGoodType.equals(FinGoodType.ALLOY)){
                    finGoodEmissions = matMass * 0.01;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.METAL)){
                    emissions = rawMatMass * 0.0039;
                } else if (rawMatType.equals(RawMatType.OTHER)) {
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.ALUMINUM)) {
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.STEEL)) {
                    emissions = rawMatMass * 0.0117;
                } else if (rawMatType.equals(RawMatType.IRON)) {
                    emissions = rawMatMass * 0;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.METAL)) {
                    emissions = matMass * 0.0042;
                } else if (finGoodType.equals(FinGoodType.ALUMINUM)) {
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.COPPER)) {
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.IRON)) {
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.STEEL)) {
                    emissions = matMass * 0.0117;
                } else if (finGoodType.equals(FinGoodType.ALLOY)) {
                    emissions = matMass * 0.01;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        }  else if (Industrial.getIndustrialType().equals(IndustrialType.PAPER_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.PAPER)){
                    rawMatEmissions = rawMatMass * 0.929;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.WOOD_CHIPS)){
                    rawMatEmissions = rawMatMass * 1.5;
                } else if (rawMatType.equals(RawMatType.SOD_HYDRO)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.SOD_SULF)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.BLEACH)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.COTTON)){
                    rawMatEmissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.CHALK)){
                    rawMatEmissions = rawMatMass * 0.44;
                } else if (rawMatType.equals(RawMatType.CLAY)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.TITANIUM_DIOX)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.ROSIN)){
                    rawMatEmissions = rawMatMass * 2.91;
                } else if (rawMatType.equals(RawMatType.GUAR_GUM)){
                    rawMatEmissions = rawMatMass * 1.63;
                } else if (rawMatType.equals(RawMatType.STARCH)){
                    rawMatEmissions = rawMatMass * 1.63;
                }
                if (finGoodType.equals(FinGoodType.PAPER)){
                    finGoodEmissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.BATH_TISSUE)){
                    finGoodEmissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.CARDBOARD)){
                    finGoodEmissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.COMP_PAPER)){
                    finGoodEmissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.NEWSPAPER)){
                    finGoodEmissions = matMass * 1.5;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.PAPER)){
                    emissions = rawMatMass * 0.929;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.WOOD_CHIPS)){
                    emissions = rawMatMass * 1.5;
                } else if (rawMatType.equals(RawMatType.SOD_HYDRO)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.SOD_SULF)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.BLEACH)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.COTTON)){
                    emissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.CHALK)){
                    emissions = rawMatMass * 0.44;
                } else if (rawMatType.equals(RawMatType.CLAY)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.TITANIUM_DIOX)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.ROSIN)){
                    emissions = rawMatMass * 2.91;
                } else if (rawMatType.equals(RawMatType.GUAR_GUM)){
                    emissions = rawMatMass * 1.63;
                } else if (rawMatType.equals(RawMatType.STARCH)){
                    emissions = rawMatMass * 1.63;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.PAPER)) {
                    emissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.BATH_TISSUE)) {
                    emissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.CARDBOARD)) {
                    emissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.COMP_PAPER)) {
                    emissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.NEWSPAPER)) {
                    emissions = matMass * 1.5;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        }  else if (Industrial.getIndustrialType().equals(IndustrialType.TEXT_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.TEXTILE)){
                    rawMatEmissions = rawMatMass * 1.05;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.COTTON)){
                    rawMatEmissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.LEATHER)){
                    rawMatEmissions = rawMatMass * 0.35;
                } else if (rawMatType.equals(RawMatType.POLYESTER)){
                    rawMatEmissions = rawMatMass * 1.28;
                }
                if (finGoodType.equals(FinGoodType.TEXTILE)){
                    finGoodEmissions = matMass * 1.006;
                } else if (finGoodType.equals(FinGoodType.COTTON)){
                    finGoodEmissions = matMass * 1.52;
                } else if (finGoodType.equals(FinGoodType.CARPET)){
                    finGoodEmissions = matMass * 1.21;
                } else if (finGoodType.equals(FinGoodType.LEATHER)){
                    finGoodEmissions = matMass * 0.35;
                } else if (finGoodType.equals(FinGoodType.POLYESTER)){
                    finGoodEmissions = matMass * 1.28;
                } else if (finGoodType.equals(FinGoodType.VINYL)){
                    finGoodEmissions = matMass * 0.67;
                } else if (finGoodType.equals(FinGoodType.WOOL)){
                    finGoodEmissions = matMass * 1.006;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.TEXTILE)){
                    emissions = rawMatMass * 1.05;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.COTTON)){
                    emissions = rawMatMass * 1.52;
                } else if (rawMatType.equals(RawMatType.LEATHER)){
                    emissions = rawMatMass * 0.35;
                } else if (rawMatType.equals(RawMatType.POLYESTER)){
                    emissions = rawMatMass * 1.28;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.TEXTILE)) {
                    emissions = matMass * 1.006;
                } else if (finGoodType.equals(FinGoodType.COTTON)) {
                    emissions = matMass * 1.52;
                } else if (finGoodType.equals(FinGoodType.CARPET)) {
                    emissions = matMass * 1.21;
                } else if (finGoodType.equals(FinGoodType.LEATHER)) {
                    emissions = matMass * 0.35;
                } else if (finGoodType.equals(FinGoodType.POLYESTER)) {
                    emissions = matMass * 1.28;
                } else if (finGoodType.equals(FinGoodType.VINYL)) {
                    emissions = matMass * 0.67;
                } else if (finGoodType.equals(FinGoodType.WOOL)) {
                    emissions = matMass * 1.006;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        }  else if (Industrial.getIndustrialType().equals(IndustrialType.CONST_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.CONST)){
                    rawMatEmissions = rawMatMass * 0.5;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.CINDER_BLOCK)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.CLAY_BRICK)){
                    rawMatEmissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.WOOD)){
                    rawMatEmissions = rawMatMass * 1.5;
                }
                if (finGoodType.equals(FinGoodType.WOOD)){
                    finGoodEmissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.CONCRETE)){
                    finGoodEmissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.CONST)){
                    finGoodEmissions = matMass * 0.75;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.CONST)){
                    emissions = rawMatMass * 1;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.CINDER_BLOCK)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.CLAY_BRICK)){
                    emissions = rawMatMass * 0;
                } else if (rawMatType.equals(RawMatType.WOOD)){
                    emissions = rawMatMass * 1.5;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.WOOD)) {
                    emissions = matMass * 1.5;
                } else if (finGoodType.equals(FinGoodType.CONCRETE)){
                    emissions = matMass * 0;
                } else if (finGoodType.equals(FinGoodType.CONST)){
                    emissions = matMass * 0.75;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        } else if (Industrial.getIndustrialType().equals(IndustrialType.PLASTIC_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.PLASTIC)){
                    rawMatEmissions = rawMatMass * 1.665;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.COAL)){
                    rawMatEmissions = rawMatMass * 2.00;
                } else if (rawMatType.equals(RawMatType.NAT_GAS)){
                    rawMatEmissions = rawMatMass * 2.80;
                } else if (rawMatType.equals(RawMatType.PETROLEUM)){
                    rawMatEmissions = rawMatMass * 3.17;
                } else if (rawMatType.equals(RawMatType.POLYESTER)){
                    rawMatEmissions = rawMatMass * 1.28;
                } else if (rawMatType.equals(RawMatType.PP)){
                    rawMatEmissions = rawMatMass * 1.27;
                } else if (rawMatType.equals(RawMatType.PS)){
                    rawMatEmissions = rawMatMass * 1.64;
                } else if (rawMatType.equals(RawMatType.PVC)){
                    rawMatEmissions = rawMatMass * 0.67;
                } else if (rawMatType.equals(RawMatType.PET)){
                    rawMatEmissions = rawMatMass * 1.28;
                } else if (rawMatType.equals(RawMatType.LDPE)){
                    rawMatEmissions = rawMatMass * 1.27;
                } else if (rawMatType.equals(RawMatType.HDPE)){
                    rawMatEmissions = rawMatMass * 1.27;
                }
                //Emissions are written as (mass) * (emissions factor)
                if (finGoodType.equals(FinGoodType.PLASTIC)){
                    finGoodEmissions = matMass * 1.2333;
                } else if (finGoodType.equals(FinGoodType.PVC)){
                    finGoodEmissions = matMass * 0.67;
                } else if (finGoodType.equals(FinGoodType.PET)){
                    finGoodEmissions = matMass * 1.28;
                } else if (finGoodType.equals(FinGoodType.PS)){
                    finGoodEmissions = matMass * 1.64;
                } else if (finGoodType.equals(FinGoodType.HDPE)){
                    finGoodEmissions = matMass * 1.27;
                } else if (finGoodType.equals(FinGoodType.LDPE)){
                    finGoodEmissions = matMass * 1.27;
                } else if (finGoodType.equals(FinGoodType.PP)){
                    finGoodEmissions = matMass * 1.27;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.PLASTIC)){
                    emissions = rawMatMass * 1.665;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.COAL)){
                    emissions = rawMatMass * 2.00;
                } else if (rawMatType.equals(RawMatType.NAT_GAS)){
                    emissions = rawMatMass * 2.80;
                } else if (rawMatType.equals(RawMatType.PETROLEUM)){
                    emissions = rawMatMass * 3.17;
                } else if (rawMatType.equals(RawMatType.POLYESTER)){
                    emissions = rawMatMass * 1.28;
                } else if (rawMatType.equals(RawMatType.PP)){
                    emissions = rawMatMass * 1.27;
                } else if (rawMatType.equals(RawMatType.PS)){
                    emissions = rawMatMass * 1.64;
                } else if (rawMatType.equals(RawMatType.PVC)){
                    emissions = rawMatMass * 0.67;
                } else if (rawMatType.equals(RawMatType.PET)){
                    emissions = rawMatMass * 1.28;
                } else if (rawMatType.equals(RawMatType.LDPE)){
                    emissions = rawMatMass * 1.27;
                } else if (rawMatType.equals(RawMatType.HDPE)){
                    emissions = rawMatMass * 1.27;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.PLASTIC)) {
                    emissions = matMass * 1.2333;
                } else if (finGoodType.equals(FinGoodType.PVC)) {
                    emissions = matMass * 0.67;
                } else if (finGoodType.equals(FinGoodType.PET)) {
                    emissions = matMass * 1.28;
                } else if (finGoodType.equals(FinGoodType.PS)) {
                    emissions = matMass * 1.64;
                } else if (finGoodType.equals(FinGoodType.HDPE)) {
                    emissions = matMass * 1.27;
                } else if (finGoodType.equals(FinGoodType.LDPE)){
                    emissions = matMass * 1.27;
                } else if (finGoodType.equals(FinGoodType.PP)){
                    emissions = matMass * 1.27;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 1 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 3 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        } else if (Industrial.getIndustrialType().equals(IndustrialType.GLASS_IND)) {
            if (roomType.equals(RoomType.PROD_FLOOR)) {
                double rawMatEmissions = 0.0;
                double finGoodEmissions = 0.0;
                if (rawMatType.equals(RawMatType.GLASS)){
                    rawMatEmissions = rawMatMass * 0.46739;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    rawMatEmissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.DOLOMITE)){
                    rawMatEmissions = rawMatMass * 0.47732;
                } else if (rawMatType.equals(RawMatType.LIMESTONE)){
                    rawMatEmissions = rawMatMass * 0.43971;
                } else if (rawMatType.equals(RawMatType.SILICA)){
                    rawMatEmissions = rawMatMass * 0.95;
                } else if (rawMatType.equals(RawMatType.SODA_ASH)){
                    rawMatEmissions = rawMatMass * 0.41492;
                } else if (rawMatType.equals(RawMatType.REC_GLASS)){
                    rawMatEmissions = rawMatMass * 0.055;
                }
                if (finGoodType.equals(FinGoodType.GLASS)){
                    finGoodEmissions = matMass * 0.055;
                }
                emissions = rawMatEmissions + finGoodEmissions;
            } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
                if (rawMatType.equals(RawMatType.GLASS)){
                    emissions = rawMatMass * 0.46739;
                } else if (rawMatType.equals(RawMatType.OTHER)){
                    emissions = rawMatMass * otherEmisFac;
                } else if (rawMatType.equals(RawMatType.DOLOMITE)){
                    emissions = rawMatMass * 0.47732;
                } else if (rawMatType.equals(RawMatType.LIMESTONE)){
                    emissions = rawMatMass * 0.43971;
                } else if (rawMatType.equals(RawMatType.SILICA)){
                    emissions = rawMatMass * 0.95;
                } else if (rawMatType.equals(RawMatType.SODA_ASH)){
                    emissions = rawMatMass * 0.41492;
                } else if (rawMatType.equals(RawMatType.REC_GLASS)){
                    emissions = rawMatMass * 0.055;
                }
            } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
                if (finGoodType.equals(FinGoodType.GLASS)) {
                    emissions = matMass * 0.055;
                }
            } else if (roomType.equals(RoomType.BREAK_ROOM)) {
                /**
                 * Standard rooms (Break, Conference, Office, and Bathroom) have two
                 * possible ways of calculating emissions:
                 * 1) If the room uses a default loading, the area of the room is
                 * multiplied by a known amount of carbon emissions per unit area
                 * 2) If the user has input all the furnishing manually into the
                 * room, the emissions are the sum total of all emissions from those
                 * objects.
                 */
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 35.034 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.OFFICE)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 21.699 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.BATHROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 2.504 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.CONF_ROOM)) {
                if (furnishingList.toString().contains(Strings.DEFAULT_LOADING.toString())) {
                    emissions = 20.395 * roomarea;
                } else if (!furnishingList.isEmpty()) {
                    emissions = furnishingList.stream().map((furnishingList1) -> furnishingList1.calculateEmissions()).reduce(emissions, (accumulator, _item) -> accumulator + _item);
                }
            } else if (roomType.equals(RoomType.FUEL_STORE)) {
                if (fuelType.equals(FuelType.LPG)) {
                    emissions = fuelVolume * 0.001 * 552.5 * 2.706;
                } else if (fuelType.equals(FuelType.BUNKER)) {
                    emissions = fuelVolume * 0.001 * 908 * 3.279;
                } else if (fuelType.equals(FuelType.DIESEL)) {
                    emissions = fuelVolume * 0.001 * 832 * 3.242;
                } else if (fuelType.equals(FuelType.GAS)) {
                    emissions = fuelVolume * 0.001 * 770 * 3.3;
                } else if (fuelType.equals(FuelType.NAT_GAS)) {
                    emissions = fuelVolume * 0.001 * 0.8 * 2.8;
                } else if (fuelType.equals(FuelType.BIODIESEL)) {
                    emissions = fuelVolume * 0.001 * 875 * 1.232;
                } else if (fuelType.equals(FuelType.FUEL)) {
                    emissions = fuelVolume * 0.001 * 656.3833 * 2.759;
                }
            }
        }
        
        if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
            if (finGoodStorage.equals(FinGoodStorageType.SHELF)) {
                int numShelves = (int) Math.round(matMass / 6500);
                //Emissions from shelf = # of shelves * 1.28 kg CO2 per shelf
                if (numShelves < 1) {
                    numShelves = 1;
                }
                storageemissions = numShelves * 1.28;
            } else if (finGoodStorage.equals(FinGoodStorageType.STEEL_PALLET)) {
                int numPallets = (int) Math.round(matMass / 4500);
                if (numPallets < 1) {
                    numPallets = 1;
                }
                //Emissions from pallet = # of pallets * mass of pallet * emissions factor
                storageemissions = numPallets * 28.127 * 0.0117;
            } else if (finGoodStorage.equals(FinGoodStorageType.WOOD_PALLET)) {
                int numPallets = (int) Math.round(matMass / 1500);
                if (numPallets < 1) {
                    numPallets = 1;
                }
                //Emissions from pallet = # of pallets * mass of pallet * emissions factor
                storageemissions = numPallets * 19.18525 * 1.5;
            }
        } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
            if (rawMatStorage.equals(RawMatStorageType.SHELF)) {
                int numShelves = (int) Math.round(rawMatMass / 6500);
                //Emissions from shelf = # of shelves * 1.28 kg CO2 per shelf
                storageemissions = numShelves * 1.28;
            } else if (rawMatStorage.equals(RawMatStorageType.STEEL_PALLET)) {
                int numPallets = (int) Math.round(rawMatMass / 4500);
                //Emissions from pallet = # of pallets * mass of pallet * emissions factor
                storageemissions = numPallets * 28.127 * 0.0117;
            } else if (rawMatStorage.equals(RawMatStorageType.WOOD_PALLET)) {
                int numPallets = (int) Math.round(rawMatMass / 1500);
                //Emissions from pallet = # of pallets * mass of pallet * emissions factor
                storageemissions = numPallets * 19.18525 * 1.5;
            }
        }

        //Multiply the result by the percentage of damage and the number of rooms:
        double totalRoomEmissions = (emissions + storageemissions) * getDamageFraction() * getRoomQuantity();
        
        return totalRoomEmissions;

    }

    public int getDamage() {
        return damage;
    }

    public void setDamage(int damage) {
        this.damage = damage;
    }

    public double getDamageFraction() {
        return damage * 0.01;
    }

    @Override
    public String toString() {
        String string = null;
        if (roomType.equals(RoomType.BATHROOM)) {
            string = (roomType.toString() + ", " + getDamage() + "% " + Strings.DAMAGE.toString()
                    + ", " + String.format("%.2f", getRoomArea()) + " m^2)" + ", " + getRoomQuantity());
        } else if (roomType.equals(RoomType.CONF_ROOM)) {
            string = (roomType.toString() + ", " + getDamage() + "% " + Strings.DAMAGE.toString()
                    + ", " + String.format("%.2f", getRoomArea()) + " m^2)" + ", " + getRoomQuantity());
        } else if (roomType.equals(RoomType.FIN_GOOD_STORE)) {
            string = (roomType.toString()) + ", " + "x" + getRoomQuantity() + ", " + getDamage() + "% " + Strings.DAMAGE.toString();
        } else if (roomType.equals(RoomType.FUEL_STORE)) {
            string = (roomType.toString()) + ", " + "x" + getRoomQuantity() + ", " + getDamage() + "% " + Strings.DAMAGE.toString();
        } else if (roomType.equals(RoomType.BREAK_ROOM)) {
            string = (roomType.toString() + ", " + getDamage() + "% " + Strings.DAMAGE.toString()
                    + ", " + String.format("%.2f", getRoomArea()) + " m^2)" + ", " + getRoomQuantity());
        } else if (roomType.equals(RoomType.OFFICE)) {
            string = (roomType.toString() + ", " + getDamage() + "% " + Strings.DAMAGE.toString()
                    + ", " + String.format("%.2f", getRoomArea()) + " m^2)" + ", " + getRoomQuantity());
        } else if (roomType.equals(RoomType.PROD_FLOOR)) {
            string = (roomType.toString()) + ", " + "x" + getRoomQuantity() + ", " + getDamage() + "% " + Strings.DAMAGE.toString();
        } else if (roomType.equals(RoomType.RAW_MAT_STORAGE)) {
            string = (roomType.toString()) + ", " + "x" + getRoomQuantity() + ", " + getDamage() + "% " + Strings.DAMAGE.toString();
        }
        return string;
    }
}

